TAsList class

Inheritance

Constructors

TAsList([List? parameters])

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the operation, like a method name.
finalinherited
nonCollectionOperation → bool
finalinherited
parameters → List?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setterinherited

Methods

clearThen() → JSONTransformer
inherited
computeOperation(Object? json) → List?
override
computeTransformation(Object? json) → dynamic
inherited
fromMatch(Match match) → TOperation
inherited
fromParameters([List? parameters]) → TAsList
override
getParameter<T>(int index, [T? def, T parser(Object v)?]) → T?
inherited
matches(String s) → Match?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parametersToString() → String
inherited
parseParameters(String? s) → List?
inherited
subParameters(int offset) → List?
inherited
then(JSONTransformer? t1, [JSONTransformer? t2, JSONTransformer? t3, JSONTransformer? t4, JSONTransformer? t5, JSONTransformer? t6, JSONTransformer? t7, JSONTransformer? t8, JSONTransformer? t9, JSONTransformer? t10]) → JSONTransformer
Other JSONTransformer to apply after this transform.
inherited
thenChain(List<JSONTransformer>? then) → JSONTransformer
inherited
toString() → String
Returns this chain of operations as String.
inherited
toStringThen(String prefix) → String
inherited
transform(Object? json) → dynamic
Transforms json using chain operations.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

NAME → String
final