TConcatenation class

Concatenate transformations

Inheritance

Constructors

TConcatenation(List<JSONTransformer> group)

Properties

group → List<JSONTransformer>
The group of transformations.
final
hashCode → int
The hash code for this object.
no setterinherited
PATTERN ↔ RegExp
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setteroverride

Methods

clearThen() → JSONTransformer
inherited
computeTransformation(Object? json) → String
override
fromMatch(Match match) → TConcatenation
override
groupsToString() → String
matches(String s) → Match?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
then(JSONTransformer? t1, [JSONTransformer? t2, JSONTransformer? t3, JSONTransformer? t4, JSONTransformer? t5, JSONTransformer? t6, JSONTransformer? t7, JSONTransformer? t8, JSONTransformer? t9, JSONTransformer? t10]) → JSONTransformer
Other JSONTransformer to apply after this transform.
inherited
thenChain(List<JSONTransformer>? then) → JSONTransformer
inherited
toString() → String
Returns this chain of operations as String.
override
toStringThen(String prefix) → String
inherited
transform(Object? json) → dynamic
Transforms json using chain operations.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

ENTRY_PATTERN → RegExp
final