TMapValue class

Transforms JSON node to a Map key value.

Inheritance

Constructors

TMapValue(List<String> keys)

Properties

hashCode → int
The hash code for this object.
no setterinherited
keys → List<String>
The keys to use for values.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setteroverride

Methods

clearThen() → JSONTransformer
inherited
computeTransformation(Object? json) → dynamic
override
fromMatch(Match match) → TMapValue
override
keysToString() → String
matches(String s) → Match?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
then(JSONTransformer? t1, [JSONTransformer? t2, JSONTransformer? t3, JSONTransformer? t4, JSONTransformer? t5, JSONTransformer? t6, JSONTransformer? t7, JSONTransformer? t8, JSONTransformer? t9, JSONTransformer? t10]) → JSONTransformer
Other JSONTransformer to apply after this transform.
inherited
thenChain(List<JSONTransformer>? then) → JSONTransformer
inherited
toString() → String
Returns this chain of operations as String.
override
toStringThen(String prefix) → String
inherited
transform(Object? json) → dynamic
Transforms json using chain operations.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

PATTERN → RegExp
final
STRING_PATTERN → RegExp
final